/*
 * TableFrame.java
 * Created on 10.02.2010 by Roland Krueger
 */
package info.rolandkrueger.demo.table;

import info.rolandkrueger.roklib.ui.swing.table.SortableFilterableTable;
import info.rolandkrueger.roklib.util.tables.filtertable.DefaultSortableFilterableTableDataModel;
import info.rolandkrueger.roklib.util.tables.filtertable.DefaultTableDataColumnHeader;
import info.rolandkrueger.roklib.util.tables.filtertable.SortableFilterableTableDataModel.SearchMode;

import java.awt.BorderLayout;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;

/**
 * @author Roland Krueger
 * @version $Id: TableFrame.java 178 2010-10-31 18:01:20Z roland $
 * 
 */
public class TableFrame extends JFrame
{
  private static final long serialVersionUID = 4689647610768378891L;

  private JPanel jContentPane = null;
  private JScrollPane scrollPane = null;
  private SortableFilterableTable<String, DefaultTableDataColumnHeader> table = null;
  private DefaultSortableFilterableTableDataModel mModel;

  /**
   * This is the default constructor
   */
  public TableFrame ()
  {
    super ();
    initialize ();
  }

  /**
   * This method initializes this
   * 
   * @return void
   */
  private void initialize ()
  {
    this.setSize (511, 437);
    this.setContentPane (getJContentPane ());
    this.setTitle ("JFrame");
  }

  /**
   * This method initializes jContentPane
   * 
   * @return javax.swing.JPanel
   */
  private JPanel getJContentPane ()
  {
    if (jContentPane == null)
    {
      jContentPane = new JPanel ();
      jContentPane.setLayout (new BorderLayout ());
      jContentPane.add (getScrollPane (), BorderLayout.CENTER);
    }
    return jContentPane;
  }

  /**
   * This method initializes scrollPane
   * 
   * @return javax.swing.JScrollPane
   */
  private JScrollPane getScrollPane ()
  {
    if (scrollPane == null)
    {
      scrollPane = new JScrollPane ();
      scrollPane.setViewportView (getTable ());
    }
    return scrollPane;
  }

  /**
   * This method initializes table
   * 
   * @return javax.swing.JTable
   */
  private JTable getTable ()
  {
    if (table == null)
    {
      mModel = new DefaultSortableFilterableTableDataModel (4, SearchMode.PREFIX_SIMILARITY);
      mModel.addStringData ("Belgium").addStringData ("17").addData (17).addData (3.14, "Brussels");
      mModel.addStringData ("Belarus").addStringData ("9").addData (9).addData (2.12, "Minsk");
      mModel.addStringData ("Australia").addStringData ("23").addData (23)
          .addData (5.17, "Canberra");
      mModel.addStringData ("Benin").addStringData ("13").addData (13).addData (1.11, "Porto-Novo");
      mModel.addStringData ("Austria").addStringData ("99").addData (99).addData (211.10, "Wien");
      mModel.setHeaderNames ("Country", "Rank", "Rank 2", "some number");
      table = new SortableFilterableTable<String, DefaultTableDataColumnHeader> (
          SearchMode.PREFIX_SIMILARITY);
      table.setModel (mModel);
      table.getTableHeader ().setReorderingAllowed (false);
      table.getTableHeader ().addMouseListener (new MouseAdapter ()
      {
        /*
         * (non-Javadoc)
         * 
         * @see
         * java.awt.event.MouseAdapter#mouseClicked(java.awt.event.MouseEvent)
         */
        @Override
        public void mouseClicked (MouseEvent e)
        {
          System.out.println ("clicked");
        }
      });
    }
    return table;
  }

} // @jve:decl-index=0:visual-constraint="21,20"
