package info.rolandkrueger.demo.tstmap;

import info.rolandkrueger.roklib.ui.swing.rapidsuggest.SuggestionComboBox;
import info.rolandkrueger.roklib.ui.swing.rapidsuggest.SuggestionComboBoxModel;
import info.rolandkrueger.roklib.util.ITernarySearchTreeMap;
import info.rolandkrueger.roklib.util.TernarySearchTreeMap;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.net.URL;
import java.net.URLConnection;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.Map;
import java.util.StringTokenizer;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.JTextField;
import javax.swing.event.CaretEvent;
import javax.swing.event.CaretListener;

/**
 * @author Roland Krueger
 * @version CVS $Id: TernarySearchTreeMapDemo.java 128 2010-03-05 06:45:32Z
 *          roland $ Created on Oct 15, 2003
 * 
 */
public class TernarySearchTreeMapDemo extends JFrame implements ActionListener, CaretListener
{
  private TernarySearchTreeMap<Integer> map;
  private TernarySearchTreeMap<String> dictMap;
  private SuggestionComboBox scb;
  private SuggestionComboBoxModel scbm;
  private JTextField tf1, tf2;
  private JTextArea ta;
  private JScrollPane sp;

  int count = 0;

  public static void main (String[] args) throws IOException
  {
    new TernarySearchTreeMapDemo ();
  }

  public TernarySearchTreeMapDemo () throws IOException
  {
    super ("Testframe for SuggestionComboBox");
    setSize (350, 400);
    this.setDefaultCloseOperation (JFrame.EXIT_ON_CLOSE);
//    map = new TernarySearchTreeMap<Integer> ();
    dictMap = new TernarySearchTreeMap<String> ();

    scbm = new SuggestionComboBoxModel (dictMap);
    scb = new SuggestionComboBox (scbm);
    scb.addActionListener (this);
    getContentPane ().setLayout (new BorderLayout (5, 5));

    tf1 = new JTextField ();
    tf2 = new JTextField ();
    tf1.addCaretListener (this);
    tf2.addCaretListener (this);
    JPanel upP = new JPanel ();
    upP.setLayout (new BorderLayout (5, 5));
    upP.add (tf1, BorderLayout.NORTH);
    upP.add (tf2, BorderLayout.SOUTH);
    getContentPane ().add (upP, BorderLayout.NORTH);

    ta = new JTextArea (50, 50);
    ta.setEditable (false);
    sp = new JScrollPane (ta);
    getContentPane ().add (sp, BorderLayout.CENTER);

//    readInWords ();
    readDictionaries ();
//    System.out.println ("Map size: " + map.size () + " distinct keys in map.");

    for (Iterator it = dictMap.entrySet ().iterator (); it.hasNext ();)
      ta.append (it.next ().toString () + "\n");

    setVisible (true);
    SelectFileDialog selectFile = new SelectFileDialog (this);
    selectFile.setVisible (true);

  }
  
  public void readDictionaries () throws IOException
  {
    System.out.println ("Reading German...");
    readDict (new File ("C:/workspace/RoKlib/dicts/de-DE.dic"), "de");    
    System.out.println ("Reading English...");
    readDict (new File ("C:/workspace/RoKlib/dicts/en-GB.dic"), "en");    
    System.out.println ("Reading Swedish...");
    readDict (new File ("C:/workspace/RoKlib/dicts/sv-SE.dic"), "sv");    
    System.out.println (dictMap.size () + " keys in map.");
  }
  
  public void readDict (File file, String lang) throws IOException
  {
    BufferedReader reader = new BufferedReader (new FileReader (file));
    String line = reader.readLine ();
    while (line != null)
    {
      String value = dictMap.get (line);
      if (value == null) value = lang;
      else value = value + " " + lang;
      dictMap.put (line, value);
      line = reader.readLine ();
    }
  }

  public void readInWords ()
  {
    long time = System.currentTimeMillis ();
    // if (true) return;
    for (int x = 0; x < 1; ++x)
    {
      ITernarySearchTreeMap<Integer> tMap = new TernarySearchTreeMap<Integer> ();
      URLConnection con;
      URL url;
      String line;
      BufferedReader reader;
      int count = 0;

      try
      {
        // url = new URL("http://www.ietf.org/iesg/1rfc_index.txt");
        // url = new URL("http://www.gutenberg.org/files/1848/1848.txt");
        // url = new URL("http://www.spiegel.de");
        // con = url.openConnection();
        // con.connect();
        // BufferedReader erzeugen, um zeilenweises Auslesen zu erm�glichen
        // reader = new BufferedReader(new
        // InputStreamReader(con.getInputStream()));
        reader = new BufferedReader (new FileReader (new File ("C:\\workspace\\RoKlib\\test.txt")));
        while (true)
        {
          line = reader.readLine ();
          if (line == null) break;
          if (line.length () == 0) continue;
          StringTokenizer st = new StringTokenizer (line);
          while (st.hasMoreTokens ())
          {
            count++;
            String token = st.nextToken ();
            if (map.indexOf (token) == - 1)
              map.put (token, new Integer (1));
            else
            {
              // System.out.println("*"+token+"*"+map.get(token)+" "+map.indexOf(token));
              // System.out.println(map.get(token).getClass()+": "+token);
              Integer i = (Integer) map.get (token);
              if (i == null) continue;
              int intV = i.intValue ();
              intV++;
              map.put (token, new Integer (intV));
            }
          }
        }
      } catch (Exception e)
      {
        e.printStackTrace ();
      }
    }
    System.out.println ("Count: " + count + " tokens in input file.");
    time = System.currentTimeMillis () - time;
    System.out.println ("Duration: " + time);
    // System.exit (0);
  }

  public void caretUpdate (CaretEvent e)
  {
    if (e.getSource () == tf1)
    {
      String prefix = tf1.getText ();
      ta.setText ("");
      if (prefix.equals ("")) return;
      long time = System.currentTimeMillis ();
      for (Iterator it = dictMap.getPrefixSubtreeIterator (prefix); it.hasNext ();)
      {
        Object o = it.next ();
        ta.append (((Map.Entry) o).getKey ().toString () + " (" + ((Map.Entry) o).getValue ()
            + ")\n");
      }

      System.out.println (System.currentTimeMillis () - time);
    }

    if (e.getSource () == tf2)
    {
      String text = tf2.getText ();
      ta.setText ("");
      for (Iterator it = dictMap.matchAlmost (text, 2, 0).iterator (); it.hasNext ();)
      {
        ta.append (it.next ().toString () + "\n");
      }
    }
  }

  public void actionPerformed (ActionEvent e)
  {
    System.out.println ("Action performed");
  }
}
