/*
 * $Id: AbstractCommandObject.java 178 2010-10-31 18:01:20Z roland $
 * Copyright (C) 2007 Roland Krueger
 * Created on 26.08.2006
 *
 * Author: Roland Krueger (www.rolandkrueger.info)
 *
 * This file is part of RoKlib.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */
package info.rolandkrueger.roklib.cli;

/**
 * This class serves as the basis for command objects in the Command design
 * pattern. Every command must be initialized with a unique command name.
 * 
 * @author Roland Krueger
 */
public abstract class AbstractCommandObject
{
  protected final String mName;

  public AbstractCommandObject (String name)
  {
    mName = name;
  }

  /**
   * Returns the name of the command object.
   * 
   * @return the name of the command object.
   */
  public String getName ()
  {
    return mName;
  }

  /**
   * Executes the command whose name is found in <tt>args[0]</tt>. The rest of
   * the <tt>args</tt> array contain the command's parameters.
   * 
   * @param args
   *          Array containing the command name as the first element and the
   *          command's parameters in the other array elements.
   * @return <tt>true</tt> if the execution of the command was successful,
   *         <tt>false</tt> otherwise. If the command object handles execution
   *         errors itself, it should return <tt>true</tt> afterwards to prevent
   *         the corresponding console from printing a default error message.
   */
  public abstract boolean run (String[] args);
}
