/*
 * $Id: CommandHandler.java 178 2010-10-31 18:01:20Z roland $
 * Copyright (C) 2007 Roland Krueger
 * Created on 04.01.2006
 *
 * Author: Roland Krueger (www.rolandkrueger.info)
 *
 * This file is part of RoKlib.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */
package info.rolandkrueger.roklib.cli;

/**
 * Classes implementing this interface will be passed the user's input to a
 * console by a {@link ConsoleThread} to process it further. The function
 * {@link CommandHandler#handleCommand(String)} is responsible to extract the
 * command name and its parameters from the input string to pass these fragments
 * to a {@link CommandInterpreter} object.
 * 
 * @author Roland Krueger
 * @see ConsoleThread
 */
public interface CommandHandler
{
  /**
   * Gets called by the {@link ConsoleThread} when the user has entered a
   * command to the console. Classes implementing this interface are then
   * responsible for extracting all relevant information from the passed string.
   * 
   * @param command
   *          The string entered by the user. This line usually contains the
   *          command's name together with its arguments.
   */
  public void handleCommand (String command);
}
