/*
 * $Id: SuggestionComboBoxModel.java 178 2010-10-31 18:01:20Z roland $
 * Copyright (C) 2003 Roland Krueger
 * Created on Oct 15, 2003
 * 
 * Author: Roland Krueger (www.rolandkrueger.info)
 *
 * This file is part of RoKlib.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */
package info.rolandkrueger.roklib.ui.swing.rapidsuggest;

import info.rolandkrueger.roklib.util.TernarySearchTreeMap;

import java.util.Collection;
import java.util.Iterator;
import java.util.Map;

import javax.swing.DefaultComboBoxModel;

/*
 * TODO: - case sensitive/case insensitive konfigurierbar machen. Dabei
 * contains()- Methode ueberarbeiten!
 */

/**
 * @author Roland Krueger (rkrueger@rumms.uni-mannheim.de)
 * @version CVS $Id: SuggestionComboBoxModel.java 128 2010-03-05 06:45:32Z
 *          roland $
 */
public class SuggestionComboBoxModel extends DefaultComboBoxModel
{
  private TernarySearchTreeMap tstMap;
  private int selectedItemIndex = - 1;

  public SuggestionComboBoxModel (Collection items)
  {
    tstMap = new TernarySearchTreeMap ();
    for (Iterator it = items.iterator (); it.hasNext ();)
    {
      Object e = it.next ();
      tstMap.put (e.toString ().toLowerCase (), e);
    }
  }

  public SuggestionComboBoxModel (Object[] items)
  {
    tstMap = new TernarySearchTreeMap ();
    for (int i = 0; i < items.length; i++)
    {
      tstMap.put (items[i].toString ().toLowerCase (), items[i]);
    }
  }

  public SuggestionComboBoxModel ()
  {
    tstMap = new TernarySearchTreeMap ();
  }

  public SuggestionComboBoxModel (TernarySearchTreeMap map)
  {
    tstMap = new TernarySearchTreeMap ();
    Map.Entry entry;
    for (Iterator it = map.entrySet ().iterator (); it.hasNext ();)
    {
      entry = (Map.Entry) it.next ();
      tstMap.put (entry.getKey ().toString ().toLowerCase (), entry.getValue ());
    }
  }

  public String getSuggestion (String prefix)
  {
    // System.out.println("getSuggestion");
    String match;
    Iterator it = tstMap.getPrefixSubtreeIterator (prefix.toLowerCase ());
    if ((it != null) && (it.hasNext ()))
      match = ((Map.Entry) it.next ()).getValue ().toString ();
    else
      match = null;
    setSelectedItem (match);
    return match;
    // if (prefix.equals("")) return null;
    // SortedSet tailSet = treeSet.tailSet(prefix.toUpperCase());
    // //System.out.println(tailSet);
    // if (tailSet.isEmpty()) return null;
    // String first = tailSet.first().toString();
    // for (Iterator it = tailSet.iterator(); it.hasNext();)
    // {
    // String element = (String) it.next();
    // if (element.toLowerCase().startsWith(prefix.toLowerCase()))
    // {
    // setSelectedItem(element);
    // return element;
    // }
    // }
    // return null;
    // for (Iterator it = treeSet.iterator(); it.hasNext();)
    // {
    // String element = (String) it.next();
    // if (element.toLowerCase().startsWith(prefix.toLowerCase()))
    // {
    // setSelectedItem(element);
    // return element;
    // }
    // }
    // return null;
  }

  public boolean contains (Object o, boolean caseSensitive)
  {
    if (caseSensitive)
      return tstMap.containsKey (o);
    else
    {
      Map.Entry entry;
      for (Iterator it = tstMap.entrySet ().iterator (); it.hasNext ();)
      {
        entry = (Map.Entry) it.next ();
        if (o.toString ().equalsIgnoreCase (entry.getKey ().toString ())) return true;
      }
    }
    return false;
  }

  public void setSelectedItem (Object anObject)
  {
    if (anObject == null)
    {
      selectedItemIndex = - 1;
      return;
    }
    selectedItemIndex = tstMap.indexOf (anObject.toString ().toLowerCase ());
  }

  public Object getSelectedItem ()
  {
    if (selectedItemIndex == - 1)
      return null;
    else
      return getElementAt (selectedItemIndex);
  }

  /*
   * (non-Javadoc)
   * 
   * @see javax.swing.MutableComboBoxModel#removeElementAt(int)
   */
  public void removeElementAt (int index)
  {
    // TODO Auto-generated method stub

  }

  /*
   * (non-Javadoc)
   * 
   * @see javax.swing.MutableComboBoxModel#addElement(java.lang.Object)
   */
  public void addElement (Object obj)
  {
    tstMap.put (obj.toString ().toLowerCase (), obj);
  }

  /*
   * (non-Javadoc)
   * 
   * @see javax.swing.MutableComboBoxModel#removeElement(java.lang.Object)
   */
  public void removeElement (Object obj)
  {
    tstMap.remove (obj);
  }

  /*
   * (non-Javadoc)
   * 
   * @see javax.swing.MutableComboBoxModel#insertElementAt(java.lang.Object,
   * int)
   */
  public void insertElementAt (Object obj, int index)
  {
    addElement (obj);
  }

  /*
   * (non-Javadoc)
   * 
   * @see javax.swing.ListModel#getSize()
   */
  public int getSize ()
  {
    return tstMap.size ();
  }

  public Object getElementAt (int index)
  {
    // Iterator it = tstMap.iterator();
    // for (int i = 0; i < index; i++)
    // {
    // it.next();
    // }
    // return it.next();
    return tstMap.getValueAt (index);
  }

  // private int indexOf(Object anObject)
  // {
  // int i = 0;
  // for (Iterator it = tstMap.iterator(); it.hasNext();)
  // {
  // if (anObject.toString().equals((String) it.next())) return i;
  // i++;
  // }
  // return -1;
  // }
}
