/*
 * $Id: ITernarySearchTreeMap.java 207 2010-11-14 18:14:17Z roland $
 * Copyright (C) 2007 Roland Krueger
 * Created on 14.11.2010
 *
 * Author: Roland Krueger (www.rolandkrueger.info)
 *
 * This file is part of RoKlib.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */
package info.rolandkrueger.roklib.util;

import java.util.Iterator;
import java.util.SortedMap;
import java.util.SortedSet;

public interface ITernarySearchTreeMap<V> extends SortedMap<CharSequence, V>
{

  /**
   * Generates an ordered list of keys that partially match the method's
   * argument key. This can be useful for spell checking or the like. The
   * method's framework and its underlying algorithm is adopted from the above
   * mentioned article on <a href="
   * http://www.javaworld.com/javaworld/jw-02-2001
   * /jw-0216-ternary.html">Javaworld</a> by Wally Flint.
   * 
   * @param key
   *          The key's <code>toString()</code> method is used to generate a
   *          string representation of that key in order to find a set of
   *          partially matching keys differing only by a number of
   *          <code>distance</code> characters.
   * @param distance
   *          The number of maximum characters that may be different from the
   *          characters of <code>key</code>.
   * @param lengthTolerance
   *          specifies by how many characters the length of the resulting set's
   *          strings may differ from the length of the search key.
   */
  public abstract SortedSet<CharSequence> matchAlmost (CharSequence key, int distance,
      int lengthTolerance);

  public abstract Entry<CharSequence, V> getEntry (Object key);

  public abstract V getValueAt (int index);

  public abstract CharSequence getKeyAt (int index);

  /**
   * Returns the index of the specified key if it is stored in the map.
   * Otherwise -1 is returned. The indexing is the same as with arrays, i.e. the
   * first element in the map has index 0 and the last element has index
   * <code>size()-1</code>.
   * 
   * @param key
   *          The key whose index is to be returned.
   * @return int the key's index or -1 if the key isn't an element of the map.
   */
  public abstract int indexOf (CharSequence key);

  public abstract Iterable<CharSequence> getKeysForPrefix (final CharSequence prefix);

  public abstract Iterator<Entry<CharSequence, V>> getPrefixSubtreeIterator (String prefix);

  public abstract Iterator<Entry<CharSequence, V>> getPrefixSubtreeIterator (String pPrefix,
      boolean inverseSearch);

  public abstract Entry<CharSequence, V> predecessor (Object keyObject);

  public abstract Entry<CharSequence, V> successor (Object keyObject);

}