/*
 * $Id: RandomStringIDGenerator.java 191 2010-11-01 17:55:17Z roland $
 * Copyright (C) 2007 Roland Krueger
 * Created on 24.07.2009
 *
 * Author: Roland Krueger (www.rolandkrueger.info)
 *
 * This file is part of RoKlib.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */
package info.rolandkrueger.roklib.util;

import info.rolandkrueger.roklib.util.helper.CheckForNull;

import java.util.Random;

/**
 * @author Roland Krueger
 * @version $Id: RandomStringIDGenerator.java 191 2010-11-01 17:55:17Z roland $
 */
public class RandomStringIDGenerator
{
  private static String sCharList = "abcdefghijklmonpqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
  private static int sCharListLength = sCharList.length ();

  public static String getUniqueID (int length, String fromCharList)
  {
    return getUniqueID (new Random (System.currentTimeMillis ()), length, fromCharList);
  }
  
  public static String getUniqueID (Random random, int length, String fromCharList)
  {
    if (length < 0) throw new IllegalArgumentException ("Length parameter < 0 not allowed.");
    if (fromCharList.trim ().isEmpty ()) 
      throw new IllegalArgumentException ("Charlist is empty.");
    CheckForNull.check (fromCharList);
    if (length == 0) return "";

    char[] buffer = new char[length];

    for (int i = 0; i < buffer.length; i++)
    {
      buffer[i] = sCharList.charAt (random.nextInt (sCharListLength));
    }
    return new String (buffer);
  }
  
  public static String getUniqueID (int length)
  {
    return getUniqueID (new Random (System.currentTimeMillis ()), length);
  }

  public static String getUniqueID (Random random, int length)
  {
    if (length < 0) throw new IllegalArgumentException ("Length parameter < 0 not allowed.");
    if (length == 0) return "";

    char[] buffer = new char[length];

    for (int i = 0; i < buffer.length; i++)
    {
      buffer[i] = sCharList.charAt (random.nextInt (sCharListLength));
    }
    return new String (buffer);
  }
}
