/*
 * $Id: TernarySearchTreeStringSet.java 211 2010-11-22 19:21:26Z roland $
 * Copyright (C) 2007 Roland Krueger
 * Created on 24.06.2007
 *
 * Author: Roland Krueger (www.rolandkrueger.info)
 *
 * This file is part of RoKlib.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */
package info.rolandkrueger.roklib.util;

import java.util.Collection;
import java.util.Comparator;
import java.util.Iterator;
import java.util.Set;
import java.util.SortedSet;

public class TernarySearchTreeStringSet implements SortedSet<CharSequence>
{
  private static Object MARKER = new Object ();

  private TernarySearchTreeMap<Object> mData;

  public TernarySearchTreeStringSet ()
  {
    mData = new TernarySearchTreeMap<Object> ();
  }

  public TernarySearchTreeStringSet (CharSequence[] values)
  {
    this ();
    for (CharSequence element : values)
    {
      add (element);
    }
  }

  public TernarySearchTreeStringSet (Set<CharSequence> values)
  {
    this ();
    for (CharSequence element : values)
    {
      add (element);
    }
  }

  public Comparator<? super CharSequence> comparator ()
  {
    return mData.comparator ();
  }

  public CharSequence first ()
  {
    return mData.firstKey ();
  }

  public SortedSet<CharSequence> headSet (CharSequence toElement)
  {
    // TODO Auto-generated method stub
    return null;
  }

  public CharSequence last ()
  {
    return mData.lastKey ();
  }

  public SortedSet<CharSequence> subSet (CharSequence fromElement, CharSequence toElement)
  {
    // TODO Auto-generated method stub
    return null;
  }

  public SortedSet<CharSequence> tailSet (CharSequence fromElement)
  {
    // TODO Auto-generated method stub
    return null;
  }

  public boolean add (CharSequence key)
  {
    return mData.put (key, MARKER) == null;
  }

  public boolean addAll (Collection<? extends CharSequence> collection)
  {
    boolean changed = false;

    for (CharSequence element : collection)
    {
      if (! mData.containsKey (element))
      {
        add (element);
        changed = true;
      }
    }
    return changed;
  }

  public void clear ()
  {
    mData.clear ();
  }

  public boolean contains (Object o)
  {
    return mData.containsKey (o);
  }

  public boolean containsAll (Collection<?> collection)
  {
    for (Object o : collection)
    {
      if (! mData.containsKey (o)) return false;
    }
    return true;
  }

  public boolean isEmpty ()
  {
    return mData.isEmpty ();
  }

  public Iterator<CharSequence> iterator ()
  {
    return mData.keySet ().iterator ();
  }

  public boolean remove (Object key)
  {
    return mData.remove (key) == MARKER;
  }

  public boolean removeAll (Collection<?> c)
  {
    boolean changed = false;

    for (Object element : c)
    {
      if (mData.containsKey (element))
      {
        changed = true;
        mData.remove (element);
      }
    }
    return changed;
  }

  public boolean retainAll (Collection<?> c)
  {
    boolean changed = false;

    for (CharSequence element : mData.keySet ())
    {
      if (! c.contains (element))
      {
        changed = true;
        mData.remove (element);
      }
    }

    return changed;
  }

  public int size ()
  {
    return mData.size ();
  }

  public Object[] toArray ()
  {
    // TODO Auto-generated method stub
    return null;
  }

  public <T> T[] toArray (T[] a)
  {
    // TODO Auto-generated method stub
    return null;
  }

  @Override
  public boolean equals (Object obj)
  {
    return mData.equals (obj);
  }

  @Override
  public int hashCode ()
  {
    return mData.hashCode ();
  }

  private int compare (CharSequence k1, CharSequence k2)
  {
    return (comparator () == null ? ((Comparable<CharSequence>) k1).compareTo (k2) : comparator ()
        .compare ((CharSequence) k1, (CharSequence) k2));
  }

  private static class TSTStringSetSubSet implements SortedSet<CharSequence>
  {
    private CharSequence mFromElement;
    private CharSequence mToElement;
    private TernarySearchTreeStringSet mParent;
    private Comparator<? super CharSequence> mComparator;

    TSTStringSetSubSet (TernarySearchTreeStringSet parent, CharSequence fromElement,
        CharSequence toElement)
    {
      if (parent.compare (fromElement, toElement) > 0)
        throw new IllegalArgumentException ("Invalid parameters: fromElement > toElement");

      mParent = parent;
      mComparator = parent.comparator ();
      mFromElement = fromElement;
      mToElement = toElement;
    }

    public Comparator<? super CharSequence> comparator ()
    {
      return mComparator;
    }

    public CharSequence first ()
    {
      // TODO Auto-generated method stub
      return null;
    }

    public SortedSet<CharSequence> headSet (CharSequence toElement)
    {
      // TODO Auto-generated method stub
      return null;
    }

    public CharSequence last ()
    {
      // TODO Auto-generated method stub
      return null;
    }

    public SortedSet<CharSequence> subSet (CharSequence fromElement, CharSequence toElement)
    {
      // TODO Auto-generated method stub
      return null;
    }

    public SortedSet<CharSequence> tailSet (CharSequence fromElement)
    {
      // TODO Auto-generated method stub
      return null;
    }

    public boolean add (CharSequence e)
    {
      // TODO Auto-generated method stub
      return false;
    }

    public boolean addAll (Collection<? extends CharSequence> c)
    {
      // TODO Auto-generated method stub
      return false;
    }

    public void clear ()
    {
      // TODO Auto-generated method stub

    }

    public boolean contains (Object o)
    {
      // TODO Auto-generated method stub
      return false;
    }

    public boolean containsAll (Collection<?> c)
    {
      // TODO Auto-generated method stub
      return false;
    }

    public boolean isEmpty ()
    {
      // TODO Auto-generated method stub
      return false;
    }

    public Iterator<CharSequence> iterator ()
    {
      // TODO Auto-generated method stub
      return null;
    }

    public boolean remove (Object o)
    {
      // TODO Auto-generated method stub
      return false;
    }

    public boolean removeAll (Collection<?> c)
    {
      // TODO Auto-generated method stub
      return false;
    }

    public boolean retainAll (Collection<?> c)
    {
      // TODO Auto-generated method stub
      return false;
    }

    public int size ()
    {
      // TODO Auto-generated method stub
      return 0;
    }

    public Object[] toArray ()
    {
      // TODO Auto-generated method stub
      return null;
    }

    public <T> T[] toArray (T[] a)
    {
      // TODO Auto-generated method stub
      return null;
    }

  }
}
