/*
 * $Id: TextFormatter.java 181 2010-11-01 09:39:13Z roland $
 * Copyright (C) 2007 Roland Krueger
 * Created on 18.11.2009
 *
 * Author: Roland Krueger (www.rolandkrueger.info)
 *
 * This file is part of RoKlib.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */
package info.rolandkrueger.roklib.util.formatter;

import info.rolandkrueger.roklib.util.helper.CheckForNull;

import java.awt.Color;

public final class TextFormatter
{
  private ITextFormatter mFormatter;
  private StringBuilder mBuffer;

  public TextFormatter (ITextFormatter formatter)
  {
    CheckForNull.check (formatter);
    mFormatter = formatter;
    mBuffer = new StringBuilder ();
  }

  public int getLength ()
  {
    return mBuffer.length ();
  }

  public void setLength (int newLength)
  {
    mBuffer.setLength (newLength);
  }

  public CharSequence getFormattedText ()
  {
    return mFormatter.encloseText (mBuffer.toString ());
  }

  public void reset ()
  {
    mBuffer = new StringBuilder ();
  }

  public TextFormatter append (CharSequence text)
  {
    mBuffer.append (mFormatter.append (text));
    return this;
  }

  public TextFormatter appendBold (CharSequence text)
  {
    mBuffer.append (mFormatter.appendBold (text));
    return this;
  }

  public TextFormatter appendColored (CharSequence text, Color color)
  {
    mBuffer.append (mFormatter.appendColored (text, color));
    return this;
  }

  public TextFormatter appendItalic (CharSequence text)
  {
    mBuffer.append (mFormatter.appendItalic (text));
    return this;
  }

  public TextFormatter appendMonospaced (CharSequence text)
  {
    mBuffer.append (mFormatter.appendMonospaced (text));
    return this;
  }

  public TextFormatter appendSubscript (CharSequence text)
  {
    mBuffer.append (mFormatter.appendSubscript (text));
    return this;
  }

  public TextFormatter appendSuperscript (CharSequence text)
  {
    mBuffer.append (mFormatter.appendSuperscript (text));
    return this;
  }

  public TextFormatter appendUnderlined (CharSequence text)
  {
    mBuffer.append (mFormatter.appendUnderlined (text));
    return this;
  }

  public TextFormatter appendStrikeThrough (CharSequence text)
  {
    mBuffer.append (mFormatter.appendStrikeThrough (text));
    return this;
  }
}
