/*
 * $Id: VisibilityGroupManager.java 178 2010-10-31 18:01:20Z roland $
 * Copyright (C) 2007 Roland Krueger
 * Created on 19.10.2009
 *
 * Author: Roland Krueger (www.rolandkrueger.info)
 *
 * This file is part of RoKlib.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */
package info.rolandkrueger.roklib.util.groupvisibility;

import info.rolandkrueger.roklib.util.conditionalengine.BooleanExpression;
import info.rolandkrueger.roklib.util.helper.CheckForNull;

import java.io.Serializable;
import java.util.Hashtable;
import java.util.Map;

public class VisibilityGroupManager implements Serializable
{
  private static final long serialVersionUID = 4836663644491428361L;

  private Map<String, VisibilityGroup> mGroups;

  public VisibilityGroupManager (int numberOfManagedObjects)
  {
    mGroups = new Hashtable<String, VisibilityGroup> (numberOfManagedObjects);
  }

  public VisibilityGroupManager ()
  {
    mGroups = new Hashtable<String, VisibilityGroup> ();
  }

  public int getGroupCount ()
  {
    return mGroups.size ();
  }

  public VisibilityGroup addGroupMember (String toGroup, IVisibilityEnablingConfigurable groupMember)
  {
    CheckForNull.check (toGroup, groupMember);
    VisibilityGroup group = createGroupIfNecessary (toGroup);
    group.addVisibilityEnablingConfigurable (groupMember);
    return group;
  }

  private VisibilityGroup createGroupIfNecessary (String groupName)
  {
    VisibilityGroup group = mGroups.get (groupName);
    if (group == null)
    {
      group = new VisibilityGroup (groupName);
      mGroups.put (groupName, group);
    }
    return group;
  }

  public VisibilityGroup getVisibilityGroup (String groupName)
  {
    return mGroups.get (groupName);
  }

  public boolean doesGroupExist (String groupName)
  {
    if (groupName == null) return false;
    return mGroups.containsKey (groupName);
  }

  public void setExpressionForVisibility (String groupName, BooleanExpression expression)
  {
    CheckForNull.check (groupName);
    VisibilityGroup group = createGroupIfNecessary (groupName);
    group.setExpressionForVisibility (expression);
  }

  public void setExpressionForEnabling (String groupName, BooleanExpression expression)
  {
    CheckForNull.check (groupName);
    VisibilityGroup group = createGroupIfNecessary (groupName);
    group.setExpressionForEnabling (expression);
  }

  public boolean setGroupVisible (String groupName, boolean visible)
  {
    CheckForNull.check (groupName);

    VisibilityGroup group = mGroups.get (groupName);
    if (group == null) return false;
    group.setVisible (visible);
    return true;
  }

  public boolean setGroupEnabled (String groupName, boolean enabled)
  {
    CheckForNull.check (groupName);

    VisibilityGroup group = mGroups.get (groupName);
    if (group == null) return false;
    group.setEnabled (enabled);
    return true;
  }
}
